@@ -53,7 +53,12 @@ int main(int argc, char *argv[]) {
 
     if (optionsResult.has_value()) {
         auto [
-        pdfPath, pageImagePaths, imageSizes, pageIndexes, imageQuality
+            pdfPath,
+            pageImagePaths,
+            imageSizes,
+            pageIndexes,
+            imageQuality,
+            dpi
         ] = optionsResult.value();
 
         std::cout << pdfPath << "\n\n";
@@ -68,7 +73,8 @@ int main(int argc, char *argv[]) {
                 pdfPath,
                 pageIndexes[i] - 1, pageImagePath,
                 renderingWidthPixels, renderingHeightPixels,
-                imageQuality
+                imageQuality,
+                dpi
                 );
 
             if (saveResult) {
